@@ -14,6 +14,7 @@ echo "Building Xpra for Python ${PYTHON_MAJOR_VERSION}.${PYTHON_MINOR_VERSION}"
 
 STRIP_DEFAULT="${STRIP_DEFAULT:=1}"
 STRIP_GSTREAMER_PLUGINS="${STRIP_GSTREAMER_PLUGINS:=$STRIP_DEFAULT}"
+GSTREAMER_VIDEO="${GSTREAMER_VIDEO:=0}"
 STRIP_SOURCE="${STRIP_SOURCE:=0}"
 STRIP_OPENGL="${STRIP_OPENGL:=$STRIP_DEFAULT}"
 CLIENT_ONLY="${CLIENT_ONLY:=0}"
@@ -26,6 +27,11 @@ DO_TESTS="${DO_TESTS:-0}"
 
 BUILDNO="${BUILDNO:="0"}"
 APP_DIR="./image/Xpra.app"
+if [ "${GSTREAMER_VIDEO}" == "1" ]; then
+  BUILD_ARGS="${BUILD_ARGS} --with-gstreamer_video"
+else
+  BUILD_ARGS="${BUILD_ARGS} --without-gstreamer_video"
+fi
 if [ "${CLIENT_ONLY}" == "1" ]; then
 	APP_DIR="./image/Xpra-Client.app"
 	BUILD_ARGS="${BUILD_ARGS} --without-server --without-shadow --without-proxy"
@@ -150,6 +156,11 @@ UVLOOPDIR="./dist/xpra.app/Contents/Resources/lib/python3.${PYTHON_MINOR_VERSION
 mkdir ${UVLOOPDIR}
 cp ${JHBUILD_PREFIX}/lib/python3.${PYTHON_MINOR_VERSION}/site-packages/uvloop/_noop.py ${UVLOOPDIR}/
 
+if [ "${GSTREAMER_VIDEO}" == "0" ]; then
+  echo "removing gstreamer video codec explicitly"
+  rm -fr "./dist/xpra.app/Contents/Resources/lib/python3.${PYTHON_MINOR_VERSION}/xpra/codecs/gstreamer"
+fi
+
 echo
 echo "*******************************************************************************"
 echo "Fixing permissions on libpython dylib"
@@ -375,11 +386,13 @@ GST_PLUGIN_DIR="./gstreamer-1.0"
 if [ "$STRIP_GSTREAMER_PLUGINS" == "1" ]; then
 	KEEP="./gstreamer-1.0.keep"
 	mkdir ${KEEP}
-	PLUGINS="app audio coreelements cutter removesilence faac faad flac oss osxaudio speex volume vorbis wav lame opus ogg gdp isomp4 matroska videoconvert x264 vpx"
+	PLUGINS="app audio coreelements cutter removesilence faac faad flac oss osxaudio speex volume vorbis wav lame opus ogg gdp isomp4 matroska"
 	#video sink for testing:
 	PLUGINS="${PLUGINS} autodetect osxvideo"
-	#video support:
-	PLUGINS="${PLUGINS} vpx x264 aom openh264 videoconvert videorate videoscale libav"
+	if [ "${GSTREAMER_VIDEO}" == "1" ]; then
+		#video support:
+		PLUGINS="${PLUGINS} vpx x264 aom openh264 videoconvert videorate videoscale libav"
+	fi
 	for x in $PLUGINS; do
 		echo "* keeping "$x
 		mv ${GST_PLUGIN_DIR}/libgst${x}* ${KEEP}/
