@@ -1,12 +1,12 @@
 #!/usr/bin/env python3
 # This file is part of Xpra.
-# Copyright (C) 2018-2020 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2018 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
 import unittest
 
-from xpra.util import AdHocStruct
+from xpra.util.objects import AdHocStruct
 from unit.server.mixins.servermixintest_util import ServerMixinTest
 from unit.process_test_util import DisplayContext
 
