@@ -5,14 +5,15 @@
 
 import sys
 
-from xpra.util import print_nested_dict
-from xpra.x11.gtk3.gdk_display_source import init_gdk_display_source
-from xpra.x11.bindings.randr import RandRBindings  #pylint: disable=no-name-in-module
+from xpra.util.str_fn import print_nested_dict
+from xpra.x11.gtk.display_source import init_gdk_display_source
+from xpra.x11.bindings.randr import RandRBindings  # pylint: disable=no-name-in-module
 
-def main():
+
+def main() -> None:
     init_gdk_display_source()
     randr = RandRBindings()
-    #print(randr.is_dummy16())
+    # print(randr.is_dummy16())
     print_nested_dict(randr.get_all_screen_properties())
 
 
